@@ -13,22 +13,22 @@ import (
 	"github.com/twpayne/chezmoi/v2/internal/chezmoitest"
 )
 
-func TestAGEEncryption(t *testing.T) {
+func TestAgeEncryption(t *testing.T) {
 	command, err := exec.LookPath("age")
 	if errors.Is(err, exec.ErrNotFound) {
 		t.Skip("age not found in $PATH")
 	}
 	require.NoError(t, err)
 
-	publicKey, privateKeyFile, err := chezmoitest.AGEGenerateKey("")
+	publicKey, privateKeyFile, err := chezmoitest.AgeGenerateKey("")
 	require.NoError(t, err)
 	defer func() {
 		assert.NoError(t, os.RemoveAll(filepath.Dir(privateKeyFile)))
 	}()
 
-	ageEncryption := &AGEEncryption{
+	ageEncryption := &AgeEncryption{
 		Command:   command,
-		Identity:  privateKeyFile,
+		Identity:  AbsPath(privateKeyFile),
 		Recipient: publicKey,
 	}
 
