@@ -34,7 +34,7 @@ import (
 	"github.com/spf13/cobra"
 	"github.com/spf13/viper"
 	"github.com/twpayne/go-shell"
-	"github.com/twpayne/go-vfs/v3"
+	"github.com/twpayne/go-vfs/v4"
 	"github.com/twpayne/go-xdg/v6"
 	"golang.org/x/term"
 
@@ -65,6 +65,7 @@ type Config struct {
 	SourceDirAbsPath chezmoi.AbsPath                 `mapstructure:"sourceDir"`
 	Template         templateConfig                  `mapstructure:"template"`
 	Umask            fs.FileMode                     `mapstructure:"umask"`
+	UseBuiltinAge    autoBool                        `mapstructure:"useBuiltinAge"`
 	UseBuiltinGit    autoBool                        `mapstructure:"useBuiltinGit"`
 
 	// Global configuration, not settable in the config file.
@@ -96,7 +97,7 @@ type Config struct {
 
 	// Encryption configurations, settable in the config file.
 	Encryption string                `mapstructure:"encryption"`
-	AGE        chezmoi.AGEEncryption `mapstructure:"age"`
+	Age        chezmoi.AgeEncryption `mapstructure:"age"`
 	GPG        chezmoi.GPGEncryption `mapstructure:"gpg"`
 
 	// Password manager data.
@@ -167,7 +168,7 @@ var (
 	persistentStateFilename = chezmoi.RelPath("chezmoistate.boltdb")
 	configStateKey          = []byte("configState")
 
-	defaultAGEEncryptionConfig = chezmoi.AGEEncryption{
+	defaultAgeEncryptionConfig = chezmoi.AgeEncryption{
 		Command: "age",
 		Suffix:  ".age",
 	}
@@ -221,6 +222,9 @@ func newConfig(options ...configOption) (*Config, error) {
 			Options: chezmoi.DefaultTemplateOptions,
 		},
 		Umask: chezmoi.Umask,
+		UseBuiltinAge: autoBool{
+			auto: true,
+		},
 		UseBuiltinGit: autoBool{
 			auto: true,
 		},
@@ -253,7 +257,7 @@ func newConfig(options ...configOption) (*Config, error) {
 		},
 
 		// Encryption configurations, settable in the config file.
-		AGE: defaultAGEEncryptionConfig,
+		Age: defaultAgeEncryptionConfig,
 		GPG: defaultGPGEncryptionConfig,
 
 		// Password manager data.
@@ -537,14 +541,14 @@ func (c *Config) cmdOutput(dirAbsPath chezmoi.AbsPath, name string, args []strin
 	return c.baseSystem.IdempotentCmdOutput(cmd)
 }
 
-func (c *Config) colorAutoFunc() (bool, error) {
+func (c *Config) colorAutoFunc() bool {
 	if _, ok := os.LookupEnv("NO_COLOR"); ok {
-		return false, nil
+		return false
 	}
 	if stdout, ok := c.stdout.(*os.File); ok {
-		return term.IsTerminal(int(stdout.Fd())), nil
+		return term.IsTerminal(int(stdout.Fd()))
 	}
-	return false, nil
+	return false
 }
 
 // defaultConfigFile returns the default config file according to the XDG Base
@@ -806,10 +810,7 @@ func (c *Config) destAbsPathInfos(sourceState *chezmoi.SourceState, args []strin
 func (c *Config) diffFile(path chezmoi.RelPath, fromData []byte, fromMode fs.FileMode, toData []byte, toMode fs.FileMode) error {
 	var sb strings.Builder
 	unifiedEncoder := diff.NewUnifiedEncoder(&sb, diff.DefaultContextLines)
-	color, err := c.Color.Value(c.colorAutoFunc)
-	if err != nil {
-		return err
-	}
+	color := c.Color.Value(c.colorAutoFunc)
 	if color {
 		unifiedEncoder.SetColor(diff.NewColorConfig())
 	}
@@ -929,6 +930,42 @@ func (c *Config) execute(args []string) error {
 	return rootCmd.Execute()
 }
 
+// filterInput reads from args (or the standard input if args is empty),
+// transforms it with f, and writes the output.
+func (c *Config) filterInput(args []string, f func([]byte) ([]byte, error)) error {
+	if len(args) == 0 {
+		input, err := io.ReadAll(c.stdin)
+		if err != nil {
+			return err
+		}
+		output, err := f(input)
+		if err != nil {
+			return err
+		}
+		return c.writeOutput(output)
+	}
+
+	for _, arg := range args {
+		argAbsPath, err := chezmoi.NewAbsPathFromExtPath(arg, c.homeDirAbsPath)
+		if err != nil {
+			return err
+		}
+		input, err := c.baseSystem.ReadFile(argAbsPath)
+		if err != nil {
+			return err
+		}
+		output, err := f(input)
+		if err != nil {
+			return err
+		}
+		if err := c.writeOutput(output); err != nil {
+			return err
+		}
+	}
+
+	return nil
+}
+
 func (c *Config) findConfigTemplate() (chezmoi.RelPath, string, []byte, error) {
 	for _, ext := range viper.SupportedExts {
 		filename := chezmoi.RelPath(chezmoi.Prefix + "." + ext + chezmoi.TemplateSuffix)
@@ -1026,6 +1063,7 @@ func (c *Config) newRootCmd() (*cobra.Command, error) {
 	persistentFlags.BoolVar(&c.Safe, "safe", c.Safe, "Safely replace files and symlinks")
 	persistentFlags.VarP(&c.SourceDirAbsPath, "source", "S", "Set source directory")
 	persistentFlags.Var(&c.Mode, "mode", "Mode")
+	persistentFlags.Var(&c.UseBuiltinAge, "use-builtin-age", "Use builtin age")
 	persistentFlags.Var(&c.UseBuiltinGit, "use-builtin-git", "Use builtin git")
 	for _, key := range []string{
 		"color",
@@ -1078,12 +1116,14 @@ func (c *Config) newRootCmd() (*cobra.Command, error) {
 		c.newChattrCmd(),
 		c.newCompletionCmd(),
 		c.newDataCmd(),
+		c.newDecryptCommand(),
 		c.newDiffCmd(),
 		c.newDocsCmd(),
 		c.newDoctorCmd(),
 		c.newDumpCmd(),
 		c.newEditCmd(),
 		c.newEditConfigCmd(),
+		c.newEncryptCommand(),
 		c.newExecuteTemplateCmd(),
 		c.newForgetCmd(),
 		c.newGitCmd(),
@@ -1237,10 +1277,7 @@ func (c *Config) persistentPreRunRootE(cmd *cobra.Command, args []string) error
 		c.errorf("warning: %s: %v\n", c.configFileAbsPath, err)
 	}
 
-	color, err := c.Color.Value(c.colorAutoFunc)
-	if err != nil {
-		return err
-	}
+	color := c.Color.Value(c.colorAutoFunc)
 	if color {
 		if err := enableVirtualTerminalProcessing(c.stdout); err != nil {
 			return err
@@ -1339,7 +1376,13 @@ func (c *Config) persistentPreRunRootE(cmd *cobra.Command, args []string) error
 
 	switch c.Encryption {
 	case "age":
-		c.encryption = &c.AGE
+		// Only use builtin age encryption if age encryption is explicitly
+		// specified. Otherwise, chezmoi would fall back to using age encryption
+		// (rather than no encryption) if age is not in $PATH, which leads to
+		// error messages from the builtin age instead of error messages about
+		// encryption not being configured.
+		c.Age.UseBuiltin = c.UseBuiltinAge.Value(c.useBuiltinAgeAutoFunc)
+		c.encryption = &c.Age
 	case "gpg":
 		c.encryption = &c.GPG
 	case "":
@@ -1348,8 +1391,8 @@ func (c *Config) persistentPreRunRootE(cmd *cobra.Command, args []string) error
 		switch {
 		case !reflect.DeepEqual(c.GPG, defaultGPGEncryptionConfig):
 			c.encryption = &c.GPG
-		case !reflect.DeepEqual(c.AGE, defaultAGEEncryptionConfig):
-			c.encryption = &c.AGE
+		case !reflect.DeepEqual(c.Age, defaultAgeEncryptionConfig):
+			c.encryption = &c.Age
 		default:
 			c.encryption = chezmoi.NoEncryption{}
 		}
@@ -1572,11 +1615,18 @@ func (c *Config) targetRelPathsBySourcePath(sourceState *chezmoi.SourceState, ar
 	return targetRelPaths, nil
 }
 
-func (c *Config) useBuiltinGitAutoFunc() (bool, error) {
-	if _, err := exec.LookPath(c.Git.Command); err == nil {
-		return false, nil
+func (c *Config) useBuiltinAgeAutoFunc() bool {
+	if _, err := exec.LookPath(c.Age.Command); err == nil {
+		return false
 	}
-	return true, nil
+	return true
+}
+
+func (c *Config) useBuiltinGitAutoFunc() bool {
+	if _, err := exec.LookPath(c.Git.Command); err == nil {
+		return false
+	}
+	return true
 }
 
 func (c *Config) validateData() error {
